@@ -4,24 +4,44 @@ spo_shape <- "68962"
 bbox <- sf::st_bbox(convert_shapes_to_sf(spo_gtfs, spo_shape))
 polygon <- sf::st_as_sf(sf::st_buffer(sf::st_as_sfc(bbox), 0))
 
+test_that("filter_by_sf is deprecated", {
+  expect_snapshot_warning(
+    filter_by_sf(spo_gtfs, bbox, sf::st_intersects, TRUE),
+    class = "deprecated_filter_by_sf"
+  )
+})
+
+tester <- function(gtfs = spo_gtfs,
+                   geom = bbox,
+                   spatial_operation = sf::st_intersects,
+                   keep = TRUE) {
+  suppressWarnings(
+    filter_by_sf(gtfs, geom, spatial_operation, keep),
+    classes = "deprecated_filter_by_sf"
+  )
+}
 
 # tests -------------------------------------------------------------------
 
 
 test_that("raises error due to incorrect input types", {
-  expect_error(filter_by_sf(unclass(spo_gtfs), bbox))
-  expect_error(filter_by_sf(spo_gtfs, unclass(bbox)))
-  expect_error(filter_by_sf(spo_gtfs, sf::st_transform(polygon, 4674)))
-  expect_error(
-    filter_by_sf(spo_gtfs, bbox, spatial_operation = "sf::st_intersect")
-  )
-  expect_error(filter_by_sf(spo_gtfs, bbox, keep = "TRUE"))
+  expect_error(tester(unclass(spo_gtfs)))
+
+  expect_error(tester(geom = unclass(bbox)))
+  expect_error(tester(geom = sf::st_transform(polygon, 4674)))
+
+  expect_error(tester(spatial_operation = "sf::st_intersect"))
+  expect_error(tester(spatial_operation = sf::st_crop))
+
+  expect_error(tester(keep = "TRUE"))
+  expect_error(tester(keep = c(TRUE, TRUE)))
+  expect_error(tester(keep = NA))
 })
 
 test_that("results in a dt_gtfs object", {
   # a dt_gtfs object is a list with "dt_gtfs" and "gtfs" classes
   dt_gtfs_class <- c("dt_gtfs", "gtfs", "list")
-  smaller_gtfs <- filter_by_sf(spo_gtfs, bbox)
+  smaller_gtfs <- tester(spo_gtfs, bbox)
   expect_s3_class(smaller_gtfs, dt_gtfs_class)
   expect_type(smaller_gtfs, "list")
 
@@ -36,23 +56,14 @@ test_that("doesn't change given gtfs", {
   gtfs <- read_gtfs(spo_path)
   expect_identical(original_gtfs, gtfs)
 
-  smaller_gtfs <- filter_by_sf(gtfs, bbox)
-  expect_false(identical(original_gtfs, gtfs))
-
-  data.table::setindex(gtfs$agency, NULL)
-  data.table::setindex(gtfs$calendar, NULL)
-  data.table::setindex(gtfs$frequencies, NULL)
-  data.table::setindex(gtfs$routes, NULL)
-  data.table::setindex(gtfs$shapes, NULL)
-  data.table::setindex(gtfs$stop_times, NULL)
-  data.table::setindex(gtfs$stops, NULL)
-  expect_identical(original_gtfs, gtfs)
+  smaller_gtfs <- tester(gtfs, bbox)
+  expect_equal(original_gtfs, gtfs, ignore_attr = TRUE)
 })
 
 test_that("supports sf, sfc and bbox objects", {
-  result1 <- filter_by_sf(spo_gtfs, polygon)
-  result2 <- filter_by_sf(spo_gtfs, sf::st_geometry(polygon))
-  result3 <- filter_by_sf(spo_gtfs, bbox)
+  result1 <- tester(spo_gtfs, polygon)
+  result2 <- tester(spo_gtfs, sf::st_geometry(polygon))
+  result3 <- tester(spo_gtfs, bbox)
 
   expect_identical(result1, result2)
   expect_identical(result1, result3)
@@ -69,11 +80,11 @@ test_that("'keep' and 'spatial_operation' arguments work correctly", {
   trips_intersected <- sf::st_intersects(polygon, trips, sparse = FALSE)
   trips_intersected <- trips[trips_intersected, ]$trip_id
 
-  smaller_keeping <- filter_by_sf(spo_gtfs, bbox)
+  smaller_keeping <- tester(spo_gtfs, bbox)
   expect_true(all(smaller_keeping$trips$trip_id %chin% trips_intersected))
   expect_true(all(smaller_keeping$shapes$shape_id %chin% shapes_intersected))
 
-  smaller_not_keeping <- filter_by_sf(spo_gtfs, bbox, keep = FALSE)
+  smaller_not_keeping <- tester(spo_gtfs, bbox, keep = FALSE)
   expect_true(!any(smaller_not_keeping$trips$trip_id %chin% trips_intersected))
   expect_true(
     !any(smaller_not_keeping$shapes$shape_id %chin% shapes_intersected)
@@ -87,7 +98,7 @@ test_that("'keep' and 'spatial_operation' arguments work correctly", {
   trips_contained <- sf::st_contains(polygon, trips, sparse = FALSE)
   trips_contained <- trips[trips_contained, ]$trip_id
 
-  smaller_keeping <- filter_by_sf(
+  smaller_keeping <- tester(
     spo_gtfs,
     bbox,
     spatial_operation = sf::st_contains
@@ -95,7 +106,7 @@ test_that("'keep' and 'spatial_operation' arguments work correctly", {
   expect_true(all(smaller_keeping$trips$trip_id %chin% trips_contained))
   expect_true(all(smaller_keeping$shapes$shape_id %chin% shapes_contained))
 
-  smaller_not_keeping <- filter_by_sf(
+  smaller_not_keeping <- tester(
     spo_gtfs,
     bbox,
     spatial_operation = sf::st_contains,
@@ -113,7 +124,7 @@ test_that("works with sf describing two features", {
   another_polygon <- sf::st_as_sf(sf::st_as_sfc(another_bbox))
   bigger_polygon <- rbind(polygon, another_polygon)
 
-  smaller_gtfs <- filter_by_sf(
+  smaller_gtfs <- tester(
     spo_gtfs,
     bigger_polygon,
     spatial_operation = sf::st_contains
@@ -128,5 +139,5 @@ test_that("works with sf describing two features", {
 test_that("error if gtfs doesn't contain neither shapes nor stop_times table", {
   spo_gtfs$shapes <- NULL
   spo_gtfs$stop_times <- NULL
-  expect_error(filter_by_sf(spo_gtfs, bbox))
+  expect_error(tester(spo_gtfs, bbox))
 })
