@@ -5,7 +5,7 @@ if (requireNamespace("zip", quietly = TRUE)) {
 
 
 data_path <- system.file("extdata/spo_gtfs.zip", package = "gtfstools")
-gtfs_url  <- "https://github.com/ipeaGIT/gtfstools/raw/master/inst/extdata/spo_gtfs.zip"
+gtfs_url  <- "https://github.com/ipeaGIT/gtfstools/raw/main/inst/extdata/spo_gtfs.zip"
 
 gtfs <- read_gtfs(data_path)
 
